==> nocc-1.8.1.tbz: www/nocc/lang/fi.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: fi.php 1931 2009-07-05 11:07:47Z gerundt $
 */

/** Finnish (Suomi)
 *
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Crt
 * @author Jarmo Järvenpää <Jarmo.Jarvenpaa@softers.net>
 */

$lang_locale = 'fi_FI.UTF-8';
$default_date_format = '%d-%m-%Y';
$no_locale_date_format = '%Y-%m-%d';
$default_time_format = '%I:%M %p';
$err_user_empty = 'Käyttäjätunnuskenttä on tyhjä';
$err_passwd_empty = 'Salasanakenttä on tyhjä';
$alt_delete = 'Poista valitut viestit';
$alt_delete_one = 'Poista viesti';
$alt_new_msg = 'Uudet viestit';
$alt_reply = 'Vastaa kirjoittajalle';
$alt_reply_all = 'Vastaa kaikille';
$alt_forward = 'Edelleenlähetä';
$alt_next = 'Seuraava';
$alt_prev = 'Edellinen';
$title_next_page = 'Seuraava sivu';
$title_prev_page = 'Edellinen sivu';
$title_next_msg = 'Seuraava viesti';
$title_prev_msg = 'Edellinen viesti';
$html_theme_label = 'Teema';
$html_welcome = 'Tervetuloa %1$s';
$html_login = 'Käyttäjätunnus';
$html_passwd = 'Salasana';
$html_submit = 'Kirjaudu sisään';
$html_help = 'Ohje';
$html_server = 'Palvelin';
$html_wrong = 'Käyttäjätunnus tai salasana on virheellinen';
$html_retry = 'Uudestaan';
$html_remember = 'Muista asetukset';
$html_msgperpage_label = 'Viestejä sivulla';
$html_preferences = 'Asetukset';
$html_full_name_label = 'Koko nimi';
$html_email_address_label = 'Sähkäpostiosoitteet';
$html_ccself = 'Kopio itsellesi';
$html_hide_addresses = 'Piilota osoitteet';
$html_outlook_quoting = 'Outlook-tyyppinen lainaus';
$html_reply_to = 'Vastaa';
$html_use_signature = 'Käytä allekirjoitusta';
$html_signature = 'Allekirjoitus';
$html_prefs_updated = 'Asetukset päivitetty';
$html_manage_folders_link = 'Hallitse IMAP-kansioita';
$html_manage_filters_link = 'Hallitse sähköpostisuodattimia';
$html_use_graphical_smilies = 'Käytä graafisia hymiöitä';
$html_sent_folder_label = 'Kopioi lähetetyt sähköpostit omaan kansioonsa';
$html_trash_folder_label = 'Siirrä poistetut sähköpostit omaan kansioonsa';
$html_send_html_mail = 'Lähetä posti HTML-muodossa';
$html_folders = 'Kansiot';
$html_folders_create_failed = 'Kansiota ei voitu luoda.';
$html_folders_rename_failed = 'Kansiota ei voitu nimetä uudelleen.';
$html_folders_updated = 'Kansiot päivitetty';
$html_folder_rename = 'Nimeä uudelleen';
$html_folder_create = 'Luo uusi kansio nimeltä';
$html_folder_delete = 'Poista';
$html_filter_remove = 'Poista';
$html_filter_body = 'Viestin teksti';
$html_filter_subject = 'Viestin aihe';
$html_filter_to = 'Kenelle-kenttä';
$html_filter_cc = 'Kopio-kenttä';
$html_filter_from = 'Keneltä-kenttä';
$html_filter_contains = 'sisältää';
$html_filter_name = 'Suodattimen nimi';
$html_filter_action = 'Suodattimen toiminto';
$html_filter_moveto = 'Siirrä kohteeseen';
$html_select_one = '--Valitse yksi--';
$html_or = 'tai';
$html_move = 'Siirrä';
$html_messages_to = 'valitut viestit kohteeseen';
$html_gotopage = 'Siirry sivulle';
$html_gotofolder = 'Siirry kansioon';
$html_other_folders = 'Kansiolista';
$html_page = 'Sivu';
$html_view_header = 'Näytä otsikot';
$html_remove_header = 'Piilota otsikot';
$html_inbox = 'Postilaatikko';
$html_new_msg = 'Uusi viesti';
$html_reply = 'Vastaa';
$html_reply_all = 'Vastaa kaikille';
$html_forward = 'Edelleenlähetä';
$html_forward_info = 'Edelleenlähetettävä viesti lähetetään tämän viestin liitteenä.';
$html_delete = 'Poista';
$html_new = 'Uusi';
$html_mark = 'Poista';
$html_att_label = 'Liite';
$html_atts_label = 'Liitteet';
$html_att_unknown = '[tuntematon]';
$html_attach = 'Liitä';
$html_attach_forget = 'Sinun täytyy liittää tiedosto(t) ennen lähetystä.';
$html_attach_delete = 'Poista valitut';
$html_attach_none = 'Sinun täytyy valita liitettävä tiedosto.';
$html_sort_by = 'Järjestele';
$html_from = 'Keneltä';
$html_subject = 'Aihe';
$html_date = 'Päivä';
$html_sent = 'Lähetä';
$html_wrote = 'kirjoitti';
$html_size = 'Koko';
$html_totalsize = 'Kokonaismäärä';
$html_bytes = 'tavua';
$html_filename = 'Tiedostonimi';
$html_to = 'Kenelle';
$html_cc = 'Kopio';
$html_nosubject = 'Ei viestin aihetta';
$html_send = 'Lähetä';
$html_cancel = 'Peruuta';
$html_no_mail = 'Ei viestiä.';
$html_logout = 'Kirjaudu ulos';
$html_msg = 'Viesti';
$html_msgs = 'Viestiä';
$html_configuration = 'Tätä palvelinta ei ole asennettu oikein.';
$html_priority_label = 'Kiireellisyys';
$html_lowest = 'Alhaisin';
$html_low = 'Matala';
$html_normal = 'Tavallinen';
$html_high = 'Korkea';
$html_highest = 'Korkein';
$html_select = 'Valitse';
$html_select_all = 'Käänteinen valinta';
$html_loading_image = 'Ladataan kuvaa';
$html_send_confirmed = 'Sähköpostisi on onnistuneesti lähetetty';
$html_no_sendaction = 'Toimintoa ei määritelty. Kokeile sallia JavaScriptin suoritus selaimessasi.';
$html_error_occurred = 'Tapahtui virhe';
$html_prefs_file_error = 'Asetustiedostoa ei voi avata kirjoitusta varten.';
$html_mark_as = 'Merkitse';
$html_unread = 'lukematon';
$html_encoding_label = 'Merkistökoodaus';
$html_add = 'Lisää';
$html_contacts = '%1$s Yhteystiedot';
$html_modify = 'Muuta';
$html_back = 'Takaisin';
$html_contact_add = 'Lisää uusi yhteystieto';
$html_contact_mod = 'Muuta yhteystietoa';
$html_contact_first = 'Etunimi';
$html_contact_last = 'Sukunimi';
$html_contact_nick = 'Lempinimi';
$html_contact_mail = 'Sähköpostiosoite';
$html_contact_del = 'yhteystietolistalta';
$html_contact_err1 = 'Yhteystietojen suurin sallittu määrä on %1$d';
$html_contact_err2 = 'Et voi lisätä uutta yhteystietoa';
$html_contact_err3 = 'Sinulla ei ole pääsyoikeuksia tähän yhteystietolistaan';
$html_del_msg = 'Poista valitut viestit?';
$html_down_mail = 'Lataa';
$original_msg = '-- Alkuperäinen viesti --';
$to_empty = 'Kenelle-kenttä ei saa olla tyhjä.';
$html_images_warning = 'Tietoturvasyistä muualla sijaitsevia kuvia ei näytetä.';
$html_images_display = 'Näytä kuvat';
$html_smtp_error_no_conn = 'SMTP-yhteyttä ei saada avattua.';
$html_smtp_error_unexpected = 'Odottamaton SMTP-vastine:';
$lang_could_not_connect = 'Palvelimeen ei saa yhteyttä.';
$lang_invalid_msg_num = 'Virheellinen viestinumero';
$html_file_upload_attack = 'Mahdollinen upload-hyökkäys palvelimelle';
$html_invalid_email_address = 'Virheellinen sähköpostiosoite';
$html_seperate_msg_win = 'Viestit erillisessä ikkunassa';
$html_err_file_contacts = 'Yhteystietotiedostoa ei voi avata kirjoitusta varten.';
$html_session_file_error = 'Istuntotiedostoa ei voi avata kirjoitusta varten.';
$html_search = 'Etsi';

==> nocc-1.8.3.tbz: www/nocc/lang/fi.php <==
<?php
/**
 * Language configuration file for NOCC
 *
 * Copyright 2001 Nicolas Chalanset <nicocha@free.fr>
 * Copyright 2001 Olivier Cahagne <cahagn_o@epita.fr>
 *
 * This file is part of NOCC. NOCC is free software under the terms of the
 * GNU General Public License. You should have received a copy of the license
 * along with NOCC.  If not, see <http://www.gnu.org/licenses/>.
 *
 * @package    NOCC
 * @subpackage Translations
 * @license    http://www.gnu.org/licenses/ GNU General Public License
 * @version    SVN: $Id: fi.php 2181 2010-04-27 09:07:03Z gerundt $
 */

/** Finnish (Suomi)
 *
 * See the qqq 'language' for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 * @author Crt
 * @author Jarmo Järvenpää <Jarmo.Jarvenpaa@softers.net>
 * @author Nike
 * @author Olli
 * @author Silvonen
 */

$lang_locale = 'fi_FI.UTF-8';
$default_date_format = '%d-%m-%Y';
$no_locale_date_format = '%Y-%m-%d';
$default_time_format = '%I:%M %p';
$err_user_empty = 'Käyttäjätunnuskenttä on tyhjä';
$err_passwd_empty = 'Salasanakenttä on tyhjä';
$alt_delete = 'Poista valitut viestit';
$alt_delete_one = 'Poista viesti';
$alt_new_msg = 'Uudet viestit';
$alt_reply = 'Vastaa kirjoittajalle';
$alt_reply_all = 'Vastaa kaikille';
$alt_forward = 'Edelleenlähetä';
$alt_next = 'Seuraava';
$alt_prev = 'Edellinen';
$title_next_page = 'Seuraava sivu';
$title_prev_page = 'Edellinen sivu';
$title_next_msg = 'Seuraava viesti';
$title_prev_msg = 'Edellinen viesti';
$html_theme_label = 'Teema:';
$html_welcome = 'Tervetuloa – %1$s';
$html_login = 'Kirjaudu';
$html_user_label = 'Käyttäjä:';
$html_passwd_label = 'Salasana:';
$html_submit = 'Kirjaudu sisään';
$html_help = 'Ohje';
$html_server_label = 'Palvelin:';
$html_wrong = 'Käyttäjätunnus tai salasana on virheellinen';
$html_retry = 'Uudestaan';
$html_remember = 'Muista asetukset';
$html_lang_label = 'Kieli:';
$html_msgperpage_label = 'Viestejä sivulla:';
$html_preferences = 'Asetukset';
$html_full_name_label = 'Koko nimi:';
$html_email_address_label = 'Sähköpostiosoite:';
$html_ccself = 'Kopio itsellesi';
$html_hide_addresses = 'Piilota osoitteet';
$html_outlook_quoting = 'Outlook-tyyppinen lainaus';
$html_reply_to = 'Vastaa';
$html_use_signature = 'Käytä allekirjoitusta';
$html_signature = 'Allekirjoitus';
$html_signature_label = 'Allekirjoitus:';
$html_reply_leadin_label = 'Vastauksen sisennin:';
$html_prefs_updated = 'Asetukset päivitetty';
$html_manage_folders_link = 'Hallitse IMAP-kansioita';
$html_manage_filters_link = 'Hallitse sähköpostisuodattimia';
$html_use_graphical_smilies = 'Käytä graafisia hymiöitä';
$html_sent_folder_label = 'Kopioi lähetetyt sähköpostit omaan kansioonsa:';
$html_trash_folder_label = 'Siirrä poistetut sähköpostit omaan kansioonsa:';
$html_colored_quotes = 'Värilliset lainaukset';
$html_display_struct = 'Näytä rakenteinen teksti';
$html_send_html_mail = 'Lähetä sähköposti HTML-muodossa';
$html_folders = 'Kansiot';
$html_folders_create_failed = 'Kansiota ei voitu luoda.';
$html_folders_sub_failed = 'Kansioon ei voitu liittyä.';
$html_folders_unsub_failed = 'Kansioon liittymistä ei voitu peruuttaa.';
$html_folders_rename_failed = 'Kansiota ei voitu nimetä uudelleen.';
$html_folders_updated = 'Kansiot päivitetty';
$html_folder_subscribe = 'Liity';
$html_folder_rename = 'Nimeä uudelleen';
$html_folder_create = 'Luo uusi kansio nimeltä';
$html_folder_remove = 'Poistu';
$html_folder_delete = 'Poista';
$html_folder_to = 'nimelle';
$html_filter_remove = 'Poista';
$html_filter_body = 'Viestin teksti';
$html_filter_subject = 'Viestin aihe';
$html_filter_to = 'Kenelle-kenttä';
$html_filter_cc = 'Kopio-kenttä';
$html_filter_from = 'Keneltä-kenttä';
$html_filter_change_tip = 'Voit muokata suodatinta korvaamalla edellisen.';
$html_reapply_filters = 'Toteuta kaikki suodattimet uudelleen';
$html_filter_contains = 'sisältää';
$html_filter_name = 'Suodattimen nimi';
$html_filter_action = 'Suodattimen toiminto';
$html_filter_moveto = 'Siirrä kohteeseen';
$html_select_one = '--Valitse yksi--';
$html_and = 'Ja';
$html_new_msg_in = 'Uudet viestit kansiossa';
$html_or = 'tai';
$html_move = 'Siirrä';
$html_copy = 'Kopioi';
$html_messages_to = 'valitut viestit kohteeseen';
$html_gotopage = 'Siirry sivulle';
$html_gotofolder = 'Siirry kansioon';
$html_other_folders = 'Kansiolista';
$html_page = 'Sivu';
$html_of = '/';
$html_view_header = 'Näytä otsikot';
$html_remove_header = 'Piilota otsikot';
$html_inbox = 'Postilaatikko';
$html_new_msg = 'Uusi viesti';
$html_reply = 'Vastaa';
$html_reply_short = 'Re:';
$html_reply_all = 'Vastaa kaikille';
$html_forward = 'Edelleenlähetä';
$html_forward_short = 'Fwd:';
$html_forward_info = 'Edelleenlähetettävä viesti lähetetään tämän viestin liitteenä.';
$html_delete = 'Poista';
$html_new = 'Uusi';
$html_mark = 'Poista';
$html_att_label = 'Liite:';
$html_atts_label = 'Liitteet:';
$html_unknown = '[tuntematon]';
$html_attach = 'Liitä';
$html_attach_forget = 'Sinun täytyy liittää tiedosto(t) ennen lähetystä.';
$html_attach_delete = 'Poista valitut';
$html_attach_none = 'Sinun täytyy valita liitettävä tiedosto.';
$html_sort_by = 'Lajittele';
$html_sort = 'Lajittele';
$html_from = 'Keneltä';
$html_from_label = 'Lähettäjä:';
$html_subject = 'Aihe';
$html_subject_label = 'Aihe:';
$html_date = 'Päiväys';
$html_date_label = 'Päiväys:';
$html_sent_label = 'Lähetä:';
$html_wrote = 'kirjoitti';
$html_size = 'Koko';
$html_totalsize = 'Kokonaismäärä';
$html_kb = 'KiB';
$html_mb = 'MiB';
$html_gb = 'GiB';
$html_bytes = 'tavua';
$html_filename = 'Tiedostonimi';
$html_to = 'Kenelle';
$html_to_label = 'Vastaanottaja:';
$html_cc = 'Kopio';
$html_cc_label = 'Kopio:';
$html_bcc_label = 'Piilokopio:';
$html_nosubject = 'Ei aihetta';
$html_send = 'Lähetä';
$html_cancel = 'Peruuta';
$html_no_mail = 'Ei viestiä.';
$html_logout = 'Kirjaudu ulos';
$html_msg = 'Viesti';
$html_msgs = 'Viestiä';
$html_configuration = 'Tätä palvelinta ei ole asennettu oikein.';
$html_priority = 'Tärkeys';
$html_priority_label = 'Tärkeys:';
$html_lowest = 'Alhaisin';
$html_low = 'Matala';
$html_normal = 'Tavallinen';
$html_high = 'Korkea';
$html_highest = 'Korkein';
$html_flagged = 'Merkitty';
$html_spam = 'Roskaposti';
$html_spam_warning = 'Tämä viesti on luokiteltu roskapostiksi.';
$html_receipt = 'Pyydä palautuskuittausta';
$html_select = 'Valitse';
$html_select_all = 'Käänteinen valinta';
$html_select_contacts = 'Valitse yhteystiedot';
$html_loading_image = 'Ladataan kuvaa';
$html_send_confirmed = 'Sähköposti lähetettiin onnistuneesti';
$html_no_sendaction = 'Toimintoa ei määritelty. Kokeile sallia JavaScriptin suoritus selaimessasi.';
$html_error_occurred = 'Tapahtui virhe';
$html_prefs_file_error = 'Asetustiedostoa ei voi avata kirjoitusta varten.';
$html_wrap = 'Mihin leveyteen lähtevät viestit rivitetään:';
$html_wrap_none = 'Ei rivitystä';
$html_usenet_separator = 'Usenet-erotin ("-- \n") ennen allekirjoitusta';
$html_mark_as = 'Merkitse';
$html_read = 'luetuksi';
$html_unread = 'lukemattomaksi';
$html_encoding_label = 'Merkistökoodaus:';
$html_add = 'Lisää';
$html_contacts = 'Yhteystiedot – %1$s';
$html_modify = 'Muuta';
$html_back = 'Takaisin';
$html_contact_add = 'Lisää uusi yhteystieto';
$html_contact_mod = 'Muuta yhteystietoa';
$html_contact_first = 'Etunimi';
$html_contact_last = 'Sukunimi';
$html_contact_nick = 'Lempinimi';
$html_contact_mail = 'Sähköpostiosoite';
$html_contact_list = 'Käyttäjän %1$s yhteystietolista';
$html_contact_del = 'yhteystietolistalta';
$html_contact_count = 'Yhteystietoja %1$d';
$html_contact_err1 = 'Yhteystietojen suurin sallittu määrä on %1$d';
$html_contact_err2 = 'Et voi lisätä uutta yhteystietoa';
$html_contact_err3 = 'Sinulla ei ole pääsyoikeuksia tähän yhteystietolistaan';
$html_contact_none = 'Yhteystietoja ei löytynyt.';
$html_del_msg = 'Poista valitut viestit?';
$html_down_mail = 'Lataa';
$original_msg = '-- Alkuperäinen viesti --';
$to_empty = 'Kenelle-kenttä ei saa olla tyhjä.';
$html_images_warning = 'Tietoturvasyistä muualla sijaitsevia kuvia ei näytetä.';
$html_images_display = 'Näytä kuvat';
$html_smtp_error_no_conn = 'SMTP-yhteyttä ei saada avattua.';
$html_smtp_error_unexpected = 'Odottamaton SMTP-vastine:';
$lang_could_not_connect = 'Palvelimeen ei saa yhteyttä.';
$lang_invalid_msg_num = 'Virheellinen viestinumero';
$html_file_upload_attack = 'Mahdollinen upload-hyökkäys palvelimelle';
$html_invalid_email_address = 'Virheellinen sähköpostiosoite';
$html_invalid_msg_per_page = 'Viestejä sivua kohden -arvo ei kelpaa';
$html_invalid_wrap_msg = 'Viestin rivitysleveys ei kelpaa';
$html_seperate_msg_win = 'Viestit erillisessä ikkunassa';
$html_err_file_contacts = 'Yhteystietotiedostoa ei voi avata kirjoitusta varten.';
$html_session_file_error = 'Istuntotiedostoa ei voi avata kirjoitusta varten.';
$html_login_not_allowed = 'Tämä kirjautuminen ei ole sallittu yhteydelle.';
$lang_err_send_delay = 'Sinun täytyy odottaa kahden sähköpostin välillä (%1$d sekuntia)';
$html_search = 'Etsi';
